pub struct YoleckCameraChoices {
pub choices: Vec<YoleckCameraChoice>,
}Expand description
Resource that defines available camera modes in the editor.
This allows users to customize which camera modes are available and add custom modes.
Example
app.insert_resource(
YoleckCameraChoices::default()
.choice_with_transform(
"Isometric",
{
let mut control = Vpeol3dCameraControl::fps();
control.mode = Vpeol3dCameraMode::Custom(2);
control.allow_rotation_while_maintaining_up = None;
control
},
Vec3::new(10.0, 10.0, 10.0),
Vec3::ZERO,
Vec3::Y,
)
);Fields
choices: Vec<YoleckCameraChoice>Implementations
Sourceimpl YoleckCameraChoices
impl YoleckCameraChoices
pub fn new() -> Self
Sourcepub fn choice(
self,
name: impl Into<String>,
control: Vpeol3dCameraControl,
) -> Self
pub fn choice( self, name: impl Into<String>, control: Vpeol3dCameraControl, ) -> Self
Add a camera mode choice without initial transform.
The camera will keep its current position when switching to this mode.
Sourcepub fn choice_with_transform(
self,
name: impl Into<String>,
control: Vpeol3dCameraControl,
position: Vec3,
look_at: Vec3,
up: Vec3,
) -> Self
pub fn choice_with_transform( self, name: impl Into<String>, control: Vpeol3dCameraControl, position: Vec3, look_at: Vec3, up: Vec3, ) -> Self
Add a camera mode choice with initial transform.
When switching to this mode, the camera will be repositioned according to
the provided position, look_at, and up parameters.