pub struct Vpeol3dCameraControl {
pub mode: Vpeol3dCameraMode,
pub plane: InfinitePlane3d,
pub allow_rotation_while_maintaining_up: Option<Dir3>,
pub proximity_per_scroll_line: f32,
pub proximity_per_scroll_pixel: f32,
pub wasd_movement_speed: f32,
pub mouse_sensitivity: f32,
}Expand description
Move and rotate a camera entity with the mouse while inside the editor.
Fields
mode: Vpeol3dCameraModeCamera mode identifier for type-safe mode comparisons.
Use this to identify which camera mode is active in custom camera systems.
plane: InfinitePlane3dDefines the plane normal for mouse wheel zoom movement.
allow_rotation_while_maintaining_up: Option<Dir3>If Some, enable mouse rotation. The up direction of the camera will be the specific
direction.
It is a good idea to match this to Vpeol3dPluginForEditor::drag_plane.
proximity_per_scroll_line: f32How much to change the proximity to the plane when receiving scroll event in
MouseScrollUnit::Line units.
proximity_per_scroll_pixel: f32How much to change the proximity to the plane when receiving scroll event in
MouseScrollUnit::Pixel units.
wasd_movement_speed: f32Movement speed for WASD controls (units per second).
mouse_sensitivity: f32Mouse sensitivity for camera rotation.
Implementations
Sourceimpl Vpeol3dCameraControl
impl Vpeol3dCameraControl
Sourcepub fn fps() -> Self
pub fn fps() -> Self
Preset for FPS-style camera control with full rotation freedom.
This mode allows complete free-look rotation with mouse and WASD movement.
Sourcepub fn sidescroller() -> Self
pub fn sidescroller() -> Self
Preset for sidescroller games, where the the game world is on the XY plane.
With this preset, the camera stays fixed looking at the scene from the side.
This combines well with Vpeol3dPluginForEditor::sidescroller.
Sourcepub fn topdown() -> Self
pub fn topdown() -> Self
Preset for games where the the game world is mainly on the XZ plane (though there can still be verticality)
This combines well with Vpeol3dPluginForEditor::topdown.